// /src/stores/order.store.ts

import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { Order } from '@/types/Order';
import * as orderService from '@/services/order';

export const useOrderStore = defineStore('order', () => {
  const orders = ref<Order[]>([]);
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // ดึงรายการ Order ทั้งหมดจาก backend
  async function fetchOrders() {
    loading.value = true;
    error.value = null;
    try {
      const response = await orderService.listOrders();
      console.log("Fetched orders from API:", response); // ✅ ตรวจสอบ API Response
      orders.value = response;
      console.log("Orders in store after update:", orders.value); // ✅ ตรวจสอบว่าถูกอัปเดตหรือไม่
    } catch (e: any) {
      error.value = e.message || "Unknown Error";
    } finally {
      loading.value = false;
    }
  }
  
  

  // ดึงข้อมูล Order รายการเดียวโดยใช้ OrderID
  async function fetchOrder(id: number): Promise<Order | null> {
    loading.value = true;
    error.value = null;
    try {
      return await orderService.getOrder(id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  // สร้าง Order ใหม่แล้วเพิ่มเข้า state
  async function addOrder(payload: Partial<Order>) {
    loading.value = true;
    error.value = null;
    try {
      const newOrder = await orderService.createOrder(payload);
      orders.value.push(newOrder);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // อัปเดต Order ที่มีอยู่ใน state
  async function editOrder(id: number, payload: Partial<Order>) {
    loading.value = true;
    error.value = null;
    try {
      const updatedOrder = await orderService.updateOrder(id, payload);
      const index = orders.value.findIndex(o => o.OrderID === id);
      if (index !== -1) {
        orders.value[index] = updatedOrder;
      }
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ลบ Order จาก backend และอัปเดต state
  async function removeOrder(id: number) {
    loading.value = true;
    error.value = null;
    try {
      await orderService.deleteOrder(id);
      orders.value = orders.value.filter(o => o.OrderID !== id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    orders,
    loading,
    error,
    fetchOrders,
    fetchOrder,
    addOrder,
    editOrder,
    removeOrder,
  };
});
