// src/stores/product.store.ts

import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { Product } from '@/types/Product';
import * as productService from '@/services/product';

export const useProductStore = defineStore('product', () => {
  const products = ref<Product[]>([]);
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // ดึงรายการ Product ทั้งหมดจาก backend
  async function fetchProducts() {
    loading.value = true;
    error.value = null;
    try {
      products.value = await productService.listProducts();
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ดึงข้อมูล Product รายการเดียวโดยใช้ ProductID
  async function fetchProduct(id: number): Promise<Product | null> {
    loading.value = true;
    error.value = null;
    try {
      return await productService.getProduct(id);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  // สร้าง Product ใหม่และเพิ่มลงใน state
  async function addProduct(payload: Partial<Product>) {
    loading.value = true;
    error.value = null;
    try {
      const newProduct = await productService.createProduct(payload);
      products.value.push(newProduct);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // อัปเดต Product ที่มีอยู่ใน state
  async function editProduct(id: number, payload: Partial<Product>) {
    loading.value = true;
    error.value = null;
    try {
      const updatedProduct = await productService.updateProduct(id, payload);
      const index = products.value.findIndex(p => p.ProductID === id);
      if (index !== -1) {
        products.value[index] = updatedProduct;
      }
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ลบ Product จาก backend และอัปเดต state
  async function removeProduct(id: number) {
    loading.value = true;
    error.value = null;
    try {
      await productService.deleteProduct(id);
      products.value = products.value.filter(p => p.ProductID !== id);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    products,
    loading,
    error,
    fetchProducts,
    fetchProduct,
    addProduct,
    editProduct,
    removeProduct,
  };
});
